@@ -548,20 +548,36 @@ setMethod("locateVariants", c("GRanges", "TxDb", "AllVariants"),
     if (length(map) > 0) {
         xHits <- map$xHits
         txHits <- map$transcriptsHits
-        if (!is.null(tx <- names(subject)[txHits]))
+        tx <- names(subject)[txHits]
+        if (!is.null(tx))
             txid <- tx
         else
             txid <- NA_integer_
         ## FIXME: cdsid is expensive
         cdsid <- IntegerList(integer(0))
+        ## CodingVariants() must fall within a coding region.
+        ## mapToTranscripts() will map ranges that span intron 
+        ## junctions and overlap multiple exons/cds regions. Because 
+        ## of this, it's possible for 'map' to return a hit for a 
+        ## query that 'map2' will not. (The subject in
+        ## 'map' is a GRangesList and in 'map2' it's unlisted.)
+        ## Only ranges identified by 'map' and 'map2' are kept.
+        ## Ranges identified by 'map' only are discarded.
         if (vtype == "coding") {
            usub <- unlist(subject) ## names needed for mapping
             map2 <- mapToTranscripts(unname(query)[xHits], usub,
                                      ignore.strand=ignore.strand)
             cds <- mcols(usub)$cds_id[map2$transcriptsHits]
             if (length(cds)) {
-                cdslst <- unique(splitAsList(cds, map2$xHits))
-                cdsid <- cdslst
+                cdsid <- unique(splitAsList(cds, map2$xHits))
+                keep <- logical(length(xHits))
+                keep[unique(map2$xHits)] <- TRUE
+                if (any(!keep)) {
+                    map <- map[keep]
+                    txHits <- map$transcriptsHits
+                    xHits <- map$xHits
+                    txid <- txid[keep] 
+                }
             }
         }
 
